hydra library
Flutter widget which helps building responsive widgets.
Classes
- HydraBehaviour
- HydraBehaviour defines behaviour for HydraWidget.
- HydraHead
- HydraHead pairs a widget with a breakpoint to define which device type the widget is intended for.
- HydraWidget
- HydraWidget is a StatelessWidget that selects which widget to display based on the current screen size and behaviour configuration.
Enums
- Breakpoint
- Breakpoint is used to distinguish between several device types.
Constants
Exceptions / Errors
- HydraNoWidgetException
- Exception thrown when no widget was provided to HydraWidget.